@@ -43,35 +43,35 @@ isNodeAlive.default <- function(x, ...) NA
 
 #' @export
 isNodeAlive.RichSOCKnode <- function(x, timeout = 0.0, ...) {
-  debug <- getOption2("parallelly.debug", FALSE)
+  debug <- isTRUE(getOption("parallelly.debug"))
   if (debug) {
-    mdebugf("isNodeAlive() for RichSOCKnode ...")
-    on.exit(mdebugf("isNodeAlive() for RichSOCKnode ... DONE"))
+    mdebug_push("isNodeAlive() for RichSOCKnode ...")
+    on.exit(mdebug_pop("isNodeAlive() for RichSOCKnode ... DONE"))
   }
 
   timeout <- as.numeric(timeout)
   stop_if_not(length(timeout) == 1L, !is.na(timeout), timeout >= 0)
-  debug && mdebugf("- Timeout: %g seconds", timeout)
+  debug && mdebugf("Timeout: %g seconds", timeout)
   
   si <- x$session_info
 
   ## Is PID available?
   pid <- si$process$pid
   if (!is.integer(pid)) {
-    debug && mdebug("- Process ID for R worker is unknown")
+    debug && mdebug("Process ID for R worker is unknown")
     return(NextMethod())
   }
 
   ## Is hostname available?
   hostname <- si$system$nodename
   if (!is.character(hostname)) {
-    debug && mdebug("- Hostname for R worker is unknown")
+    debug && mdebug("Hostname for R worker is unknown")
     return(NextMethod())
   }
 
   ## Are we running on that host?
   if (identical(hostname, Sys.info()[["nodename"]])) {
-    debug && mdebug("- The R worker is running on the current host")
+    debug && mdebug("The R worker is running on the current host")
     if (timeout > 0) {
       setTimeLimit(cpu = timeout, elapsed = timeout, transient = TRUE)
       on.exit({
@@ -87,7 +87,7 @@ isNodeAlive.RichSOCKnode <- function(x, timeout = 0.0, ...) {
     return(res)
   }
 
-  debug && mdebug("- The R worker is running on another host")
+  debug && mdebug("The R worker is running on another host")
   
   ## Can we connect to the host?
   options <- attr(x, "options")
@@ -99,24 +99,25 @@ isNodeAlive.RichSOCKnode <- function(x, timeout = 0.0, ...) {
 
   ## Command to call Rscript -e 
   code <- sprintf("cat(%s:::pid_exists(%d))", .packageName, pid)
-  rscript_args <- paste(c("-e", shQuote(code, type = rscript_sh)), collapse = " ")
+  rscript_args <- paste(c("-e", shQuote(code, type = rscript_sh[1])), collapse = " ")
   cmd <- paste(rscript, rscript_args)
-  debug && mdebugf("- Rscript command to be called on the other host: %s", cmd)
+  debug && mdebugf("Rscript command to be called on the other host: %s", cmd)
   stop_if_not(length(cmd) == 1L)
 
   rshopts <- args_org$rshopts
   if (length(args_org$user) == 1L) rshopts <- c("-l", args_org$user, rshopts)
+  rshopts <- paste(rshopts, collapse = " ")
   rsh_call <- paste(paste(shQuote(rshcmd), collapse = " "), rshopts, worker)
-  debug && mdebugf("- Command to connect to the other host: %s", rsh_call)
+  debug && mdebugf("Command to connect to the other host: %s", rsh_call)
   stop_if_not(length(rsh_call) == 1L)
 
-  local_cmd <- paste(rsh_call, shQuote(cmd, type = rscript_sh))
-  debug && mdebugf("- System call: %s", local_cmd)
+  local_cmd <- paste(rsh_call, shQuote(cmd, type = rscript_sh[2]))
+  debug && mdebugf("System call: %s", local_cmd)
   stop_if_not(length(local_cmd) == 1L)
 
   ## system() ignores fractions of seconds, so need to be at least 1 second
   if (timeout > 0 && timeout < 1) timeout <- 1.0
-  debug && mdebugf("- Timeout: %g seconds", timeout)
+  debug && mdebugf("Timeout: %g seconds", timeout)
 
   ## system() does not support argument 'timeout' in R (<= 3.4.0)
   if (getRversion() < "3.5.0") {
@@ -129,9 +130,9 @@ isNodeAlive.RichSOCKnode <- function(x, timeout = 0.0, ...) {
     system(local_cmd, intern = TRUE, ignore.stderr = TRUE, timeout = timeout)
   }, condition = function(w) {
     reason <<- conditionMessage(w)
-    debug && mdebugf("- Caught condition: %s", reason)
+    debug && mdebugf("Caught condition: %s", reason)
   })
-  debug && mdebugf("- Results: %s", res)
+  debug && mdebugf("Results: %s", res)
   status <- attr(res, "status")
   res <- as.logical(res)
   if (length(res) != 1L || is.na(res)) {
@@ -140,12 +141,12 @@ isNodeAlive.RichSOCKnode <- function(x, timeout = 0.0, ...) {
     
     msg <- sprintf("Could not infer whether %s node is alive", sQuote(class(x)[1]))
     if (!is.null(reason)) {
-      debug && mdebugf("- Reason: %s", reason)
+      debug && mdebugf("Reason: %s", reason)
       msg <- sprintf("%s. Reason reported: %s", msg, reason)
     }
 
     if (!is.null(status)) {
-      debug && mdebugf("- Status: %s", status)
+      debug && mdebugf("Status: %s", status)
       msg <- sprintf("%s [exit code: %d]", msg, status)
     }
 
